changeset 11073:5d673ad5f710

version-etc: Add emit_bug_reporting_address.
author Simon Josefsson <simon@josefsson.org>
date Fri, 23 Jan 2009 16:01:59 +0100
parents 2017a2abcff4
children 8cf858130820
files ChangeLog lib/version-etc.c lib/version-etc.h modules/version-etc
diffstat 4 files changed, 27 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,10 @@
+2009-01-23  Simon Josefsson  <simon@josefsson.org>
+
+	* lib/version-etc.c: Add emit_bug_reporting_address, inspired by
+	GNU CoreUtils.
+	* lib/version-etc.h: Add prototype for emit_bug_reporting_address.
+	* modules/version-etc (Description): Update.
+
 2009-01-22  Bruno Haible  <bruno@clisp.org>
 
 	Cache the C locale object.
--- a/modules/version-etc
+++ b/modules/version-etc
@@ -1,5 +1,5 @@
 Description:
-Print --version output.
+Print --version and bug-reporting information in a consistent format.
 
 Files:
 lib/version-etc.h
--- a/lib/version-etc.c
+++ b/lib/version-etc.c
@@ -1,4 +1,4 @@
 /* Utility to help print --version output in a consistent format.
    Copyright (C) 1999-2009 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -170,3 +170,16 @@
   va_start (authors, version);
   version_etc_va (stream, command_name, package, version, authors);
 }
+
+void
+emit_bug_reporting_address (void)
+{
+  /* TRANSLATORS: The placeholder indicates the bug-reporting address
+     for this package.  Please add _another line_ saying
+     "Report translation bugs to <...>\n" with the address for translation
+     bugs (typically your translation team's web or email address).  */
+  printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
+  printf (_("%s home page: http://www.gnu.org/software/%s/\n"),
+	  PACKAGE_NAME, PACKAGE);
+  printf (_("General help using GNU software: http://www.gnu.org/gethelp/\n"));
+}
@@ -1,4 +1,4 @@
-/* Utility to help print --version output in a consistent format.
+/* Print --version and bug-reporting information in a consistent format.
    Copyright (C) 1999-2009 Free Software Foundation, Inc.
 
--- a/lib/version-etc.h
+++ b/lib/version-etc.h
@@ -1,5 +1,5 @@
-/* Utility to help print --version output in a consistent format.
-   Copyright (C) 1999, 2003, 2005 Free Software Foundation, Inc.
+/* Print --version and bug-reporting information in a consistent format.
+   Copyright (C) 1999, 2003, 2005, 2009 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -31,6 +31,8 @@
 extern void version_etc (FILE *stream,
 			 const char *command_name, const char *package,
 			 const char *version,
-		         /* const char *author1, ...*/ ...);
+			 /* const char *author1, ...*/ ...);
+
+extern void emit_bug_reporting_address (void);
 
 #endif /* VERSION_ETC_H */